TileMask34

Struct TileMask34 

pub struct TileMask34(pub u64);
1-bit-per-tile version of TileSet34, i.e. non-multi set, set of tile kinds.

Tuple Fields

0: u64

Implementations

Source

impl TileMask34

pub fn new(__0: u64) -> TileMask34

Source

impl TileMask34

pub const fn empty_set() -> Self

An empty tile set.

pub const fn complete_set() -> Self

The complete set of tiles (all 34 kinds).

pub fn is_empty(self) -> bool

Returns if this is an empty set.

pub fn any(self) -> bool

Returns if there is at least one kind of tile in the set.

pub fn has(self, tile: Tile) -> bool

Tests if this set contains the given tile.

pub fn has_i(self, i: u8) -> bool

Tests if this set contains the given tile encoding.

pub fn set(&mut self, tile: Tile)

Mutates the set to include the given tile.

pub fn clear(&mut self, tile: Tile)

Mutates the set to exclude the given tile.