TileSet37

Struct TileSet37 

pub struct TileSet37(pub [u8; 37]);
Histogram for all 37 kinds of tiles (including reds). Can be directly indexed with Tile.

Tuple Fields

0: [u8; 37]

Implementations

Source

impl TileSet37

pub fn new(__0: [u8; 37]) -> TileSet37

Source

impl TileSet37

pub const fn empty_set() -> Self

An empty tile set.

pub const fn complete_set(num_reds: [u8; 3]) -> Self

The complete set of tiles in a game, given the number of red 5’s in play. Each red 5 replaces its corresponding normal 5; the total number of tiles remains 136 (34 x 4).

pub fn packed_34(&self) -> [u32; 4]

Same as super::TileSet34::packed_34, but collapsing red 5’s into normal 5’s.

pub fn iter_tiles(&self) -> impl Iterator<Item = Tile>

Iterates through all tiles in this tile set, in encoding order (i.e. reds come after honors).